@@ -1,4 +1,3 @@
-
 class FinstmtException(Exception):
     pass
 
@@ -49,3 +48,11 @@ class BalanceSheetNotBalancedException(ForecastException):
 
 class InvalidForecastEquationException(ForecastException):
     pass
+
+
+class InvalidBalancePlugsException(ForecastException):
+    pass
+
+
+class InvalidBalanceConfigException(ForecastException):
+    pass
