@@ -1,7 +1,7 @@
 from typing import Optional
 
-import pandas as pd
 import numpy as np
+import pandas as pd
 
 from finstmt.exc import ForecastNotFitException
 from finstmt.forecast.models.base import ForecastModel
@@ -16,11 +16,11 @@ class RecentValueModel(ForecastModel):
 
     def predict(self) -> pd.Series:
         if self.orig_series is None:
-            raise ForecastNotFitException('call .fit before .predict')
+            raise ForecastNotFitException("call .fit before .predict")
         all_dates = np.concatenate((self.orig_series.index, self._future_date_range))
         df = pd.DataFrame(index=all_dates)
-        df['mean'] = self.recent
+        df["mean"] = self.recent
         self.result_df = df
-        self.result = df['mean'].loc[self._future_date_range]
+        self.result = df["mean"].loc[self._future_date_range]
         super().predict()
         return self.result
