@@ -1,11 +1,11 @@
 import logging
 import sys
 
-logger = logging.getLogger('finstmt')
+logger = logging.getLogger("finstmt")
 logger.setLevel(logging.INFO)
-formatter = logging.Formatter('%(levelname)s: %(message)s')
+formatter = logging.Formatter("%(levelname)s: %(message)s")
 
 ch = logging.StreamHandler(stream=sys.stdout)
 ch.setLevel(logging.DEBUG)
 ch.setFormatter(formatter)
-logger.addHandler(ch)
\ No newline at end of file
+logger.addHandler(ch)
